#
# spec file for package python-aws-sam-translator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Disable tests on SLE-12 due to issues with Python 3.4
# see: https://github.com/awslabs/serverless-application-model/issues/1255
%if 0%{?suse_version} < 1500
%bcond_with test
%else
%bcond_without test
%endif
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-aws-sam-translator
Version:        1.71.0
Release:        1.1
Summary:        AWS SAM template to AWS CloudFormation template translator
License:        Apache-2.0
URL:            https://github.com/awslabs/serverless-application-model
Source:         https://github.com/awslabs/serverless-application-model/archive/v%{version}.tar.gz#/serverless-application-model-%{version}.tar.gz
Patch0:         skip-tests-require-network.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-boto3 >= 1.19.5
Requires:       python-jsonschema >= 3.2
Requires:       python-pydantic >= 1.8
Requires:       (python-typing_extensions >= 4.4.0 if python-base < 3.7)
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%if 0%{?suse_version} < 1500
BuildRequires:  python
%endif
# SECTION test requirements
BuildRequires:  %{python_module PyYAML >= 5.4}
BuildRequires:  %{python_module boto3 >= 1.19.5}
BuildRequires:  %{python_module coverage >= 5.3}
BuildRequires:  %{python_module docopt >= 0.6.2}
BuildRequires:  %{python_module jsonschema >= 3.2}
BuildRequires:  %{python_module parameterized >= 0.7.4}
BuildRequires:  %{python_module pydantic >= 1.8}
BuildRequires:  %{python_module pytest >= 3.0.7}
BuildRequires:  %{python_module pytest-cov >= 2.10.1}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module requests >= 2.24.0}
%python_subpackages

%description
AWS SAM Translator is a library that transform SAM
templates into AWS CloudFormation templates

%prep
%autosetup -p1 -n serverless-application-model-%{version}
sed -i -e 's:~=:>=:g' requirements/base.txt
# Remove the __init__.py file from bin to avoid installation of this
# folder in python_sitelib
# https://github.com/aws/serverless-application-model/issues/2588
rm bin/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

mkdir -p %{buildroot}%{_bindir}
install -D -m 755 bin/sam-translate.py %{buildroot}%{_bindir}/sam-translate
%python_clone -a %{buildroot}%{_bindir}/sam-translate

%if %{with test}
%check
export LANG=en_US.UTF8
# test_is_service_supported_positive_4_ec2:
#   samtranslator/region_configuration.py:52: NoRegionFound
# test_errors_13_error_definitionuri:
#   AssertionError: Expected 7 errors, found 9
%pytest -k 'not (test_is_service_supported_positive_4_ec2 or test_errors_13_error_definitionuri or test_py27_hash)'
%endif

%post
%python_install_alternative sam-translate

%postun
%python_uninstall_alternative sam-translate

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/sam-translate
%{python_sitelib}/samtranslator
%{python_sitelib}/aws_sam_translator-%{version}*-info

%changelog
* Fri Sep  1 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.74.0
  * fix:RuntimeManagementConfig by @ConnorRobertson in #3274
  * chore: update schema by @ConnorRobertson in #3276
  * Merge main to develop by @ConnorRobertson in #3278
  * chore: switch to SimpleTable in gql integ tests by @ssenchenko in #3279
  * chore: Update Lambda envs in integ tests by @ssenchenko in #3280
  * fix: Fix Propagate Tags when Tags is defined in Globals by @GavinZZ in #3284
  * feat: Input transformer for AWS::Serverless::Function.EventBridgeRule
    by @ConnorRobertson in #3283
  * Release 1.74.0 (to main) by @xazhao in #3329
- from version 1.73.0
  * chore(schema): update by @github-actions in #3267
  * chore(schema): update by @github-actions in #3266
  * ci: fail tests on warnings by @hoffa in #3248
  * chore(schema): update by @github-actions in #3272
  * Release 1.73.0 (to main) by @ssenchenko in #3295
- from version 1.72.0
  * Merge main to develop by @GavinZZ in #3226
  * fix: read from default boto3 session if present. by @sriram-mv in #3224
  * chore(schema): update by @github-actions in #3227
  * chore: use auto-generated CFN docs from CDK by @hoffa in #3219
  * docs: update schema diagram by @hoffa in #3229
  * docs: add schema workflow badge by @hoffa in #3230
  * chore: update SAM schema docs by @hoffa in #3232
  * chore: remove SAM schema docs automation by @hoffa in #3233
  * chore(schema): update by @github-actions in #3234
  * docs: update schema diagram by @hoffa in #3235
  * chore(schema): update by @github-actions in #3238
  * chore(schema): update by @github-actions in #3239
  * chore(schema): update by @github-actions in #3241
  * Set runtime for resolvers which use generated code by @ssenchenko in #3240
  * Merge main to develop by @hoffa in #3243
  * chore(schema): update by @github-actions in #3244
  * chore(schema): update by @github-actions in #3247
  * optional table-arn for ddb datasource by @ssenchenko in #3250
  * chore: update managed policies by @hoffa in #3251
  * chore(schema): update by @github-actions in #3252
  * allow intrinsics for some less important fields by @ssenchenko in #3253
  * add "graphqlapi:createdBy": "SAM" tag by @ssenchenko in #3254
  * chore(schema): update by @github-actions in #3255
  * chore: remove legacy schema validation code by @hoffa in #3257
  * chore: json schema docs update by @ssenchenko in #3256
  * chore(schema): update by @github-actions in #3259
  * Release 1.72.0 (to main) by @ConnorRobertson in #3277
- from version 1.71.0
  * chore(schema): update by @github-actions in #3192
  * chore: make statemachine cw events test nonblocking by @aaythapa in #3196
  * feat: make add_transform_test.py always match expected output by @hoffa in #3195
  * Allow SAM Api and HttpApi to Propagate Tags to Generated
    Resources by @GavinZZ in #3193
  * Allow SAM Function and SAM StateMachines to Propagate
    Tags to Generated Resources by @GavinZZ in #3200
  * chore(schema): update by @github-actions in #3199
  * chore: add test with Function and CloudWatch event by @hoffa in #3204
  * chore(schema): update by @github-actions in #3202
  * chore(schema): update by @github-actions in #3205
  * chore(schema): update by @github-actions in #3206
  * chore(schema): update by @github-actions in #3207
  * chore(schema): update by @github-actions in #3208
  * Merge main to develop by @xazhao in #3212
  * chore: remove ephemeral storage integ test by @xazhao in #3213
  * fix: Remove validation of SNS Event FilterPolicy by @xazhao in #3216
  * chore: use explicit main branch for SAM docs by @hoffa in #3217
  * chore: Add transform tests with Tracing Properties by @GavinZZ in #3221
  * feat: add --stdout to sam-translate.py by @hoffa in #3222
  * feat: Support Disabled Tracing Configuration by @GavinZZ in #3223
  * Release 1.71.0 (to main) by @hoffa in #3242
- from version 1.70.0
  * feat: Add AutoPublishAlias to StateMachine for managed traffic shifting
  * feat: Add StartingPositionTimestamp to SelfManagedKafka
  * Release 1.70.0 (to main) by @GavinZZ in (#3225)
- from version 1.69.0
  * chore(schema): update by @github-actions in #3156
  * chore(schema): update by @github-actions in #3159
  * chore(schema): update by @github-actions in #3162
  * chore(schema): update by @github-actions in #3160
  * chore(schema): update by @github-actions in #3164
  * docs: clarify success/failure transform tests by @hoffa in #3165
  * Merge main to develop by @hoffa in #3168
  * chore: make MSK tests non-blocking by @hoffa in #3170
  * chore: run schema update earlier in the day by @hoffa in #3174
  * chore: Upgrade ruff to 0.0.269 by @aahung in #3173
  * chore(schema): update by @github-actions in #3175
  * chore(schema): update by @github-actions in #3178
  * chore: Get CFN resource properties from profiles.json
    for SAM Connectors by @GavinZZ in #3176
  * Update MQ Autogen Role Test As Non Blocking by @GavinZZ in #3182
  * chore(schema): update by @github-actions in #3184
  * Merge main to develop by @GavinZZ in #3186
  * chore(schema): update by @github-actions in #3187
  * docs: fix schema links by @hoffa in #3188
  * chore: bundle aws-us-gov AWS managed policies by @hoffa in #3189
  * chore: make custom domains api test nonblocking by @aaythapa in #3191
  * chore(schema): update by @github-actions in #3190
  * Release 1.69.0 (to main) by @xazhao in #3211
- from version 1.68.0
  * chore: Upgrade ruff to 0.0.263 and enable more rules by @aahung in #3127
  * docs: mention what transform tests are by @hoffa in #3129
  * chore(schema): update by @github-actions in #3131
  * Merge main to develop by @ssenchenko in #3136
  * feat: actionable error on non-ARN policy by @hoffa in #3132
  * chore(schema): update by @github-actions in #3137
  * feat(SimpleTable): add PointInTimeRecoverySpecification by @hoffa in #3138
  * chore(schema): update by @github-actions in #3139
  * chore: mark test_request_parameters_open_api
    as @nonblocking by @hoffa in #3141
  * chore(schema): update by @github-actions in #3143
  * docs: remove automatic type/bug label by @hoffa in #3147
  * chore(schema): update by @github-actions in #3148
  * chore: update bundled managed policies by @hoffa in #3149
  * chore(schema): update by @github-actions in #3150
  * AppSync Api -> Lambda connector by @ssenchenko in #3145
  * Revert "feat: actionable error on non-ARN policy #3132" by @hoffa in #3153
  * chore: add Policies test with every type by @hoffa in #3155
  * Release 1.68.0 (to main) by @GavinZZ in #3185
- from version 1.67.0
  * chore(schema): update by @github-actions in #3104
  * chore: Enable termination protection for companion
    stacks by @GavinZZ in #3105
  * chore(schema): update by @github-actions in #3108
  * fix: Availability Dip Fix for MergeDefinitions
    property by @GavinZZ in #3115
  * chore(schema): update by @github-actions in #3116
  * chore: bundle aws-cn AWS managed policies by @hoffa in #3117
  * Merge main to develop by @xazhao in #3119
  * fix: Add ScheduleV2 OmitName to omit generated Name in
    Scheduler::Schedule by @aahung in (#3120)
  * chore: Use importlib.metadata to get package
    version by @aahung in #3121
  * chore(schema): update by @github-actions in #3124
  * chore: Add sar_client_creator to ServerlessAppPlugin
    constructor by @aahung in #3126
  * Release 1.67.0 (to main) by @hoffa in #3167
- from version 1.66.0
  * chore: Use TypeGuard to avoid unncessary type casts by @aahung in #3090
  * chore(schema): update by @github-actions in #3092
  * chore: Fix public_interface not catching all constants and
    enable Path rules (ruff 0.261) by @aahung in #3091
  * Merge main to develop by @aahung in #3094
  * chore: Enable DynamoDB on demand mode by @GavinZZ in #3098
  * chore(schema): update by @github-actions in #3096
  * chore(schema): update by @github-actions in #3099
  * chore: update bundled managed policies by @hoffa in #3100
  * chore: remove mix destination connector integ test because
    transform test is… by @xazhao in #3101
  * Release 1.66.0 (to main) by @ssenchenko in #3135
- from version 1.65.0
  * feat: scaffolding for improved pass-throughs in schema by @hoffa in #3055
  * feat: improve schema pass-through handling by @hoffa in #3056
  * chore: more improved schema pass-throughs by @hoffa in #3057
  * fix: pin cfn-lint to bypass issue in latest by @hoffa in #3063
  * fix: Fix availability dip from API MergeDefinitions property by @GavinZZ in #3062
  * chore: improve cfn-lint install by @hoffa in #3064
  * fix: Shorten Location IndexName property by @GavinZZ in #3065
  * chore: more improved pass-through schemas by @hoffa in #3060
  * Merge main to develop by @GavinZZ in #3069
  * chore: Upgrade ruff to 0.0.259 and enable C4 rules by @aahung in #3066
  * chore: remove description in favor of markdownDescription by @hoffa in #3068
  * chore: more typed schema pass-throughs by @hoffa in #3072
  * chore(schema): update by @github-actions in #3074
  * chore: and more typed schema pass-throughs by @hoffa in #3078
  * fix: Add Name property to SAM Statemachine EventBridgeRule event by @aaythapa in #3087
  * chore(schema): update by @github-actions in #3084
  * fix: Connector "Type" cannot be Serverless resource types by @GavinZZ in #3088
  * Release 1.65.0 (to main) by @xazhao in #3118
- from version 1.64.0
  * chore(schema): update by @github-actions in #3034
  * chore: run test coverage command in parallel by @aaythapa in #3037
  * feat: Add a new property SeparateRecordSetGroup to
    disable merging into record set group by @xazhao in #2993
  * chore: upgrade mypy by @hoffa in #3039
  * fix: add DeletionProtection to AWS::Cognito::UserPool by @hoffa in #3041
  * docs: add clause about internal to guidelines by @hoffa in #3044
  * chore(schema): update by @github-actions in #3043
  * fix: Skip MQ Integ Test and add it to Transform Test by @GavinZZ in #3045
  * feat: allow classes that inherit Resource to disable
    setattr validation by @pradhapanr in #3047
  * chore(schema): update by @github-actions in #3048
  * feat: appsync datasource to lambda connector by @ssenchenko in #3046
  * fix: integ test for AppSync DataSource -> DDB connector by @ssenchenko in #3049
  * chore: update schema docs by @hoffa in #3052
  * Release 1.64.0 (to main) by @aahung in #3093
  * feat: Support InvokeMode in lambda function URL config by @valerena
- from version 1.63.0
  * chore: adding some type checks as constants by @xazhao in #2986
  * feat: new SESBulkTemplatedCrudPolicy_v2 policy by @aaythapa in #2929
  * chore: fix local transform format by @xazhao in #2990
  * ci: test on Python 3.11 by @hoffa in #2991
  * chore: add Python 3.11 to classifiers by @hoffa in #2992
  * chore(schema): update by @github-actions in #2994
  * chore(schema): update by @github-actions in #2997
  * Feature: SNS Event FilterPolicyScope attribute by @mustafa-sadiq in #2988
  * ci: ignore unused parameter cfn-lint rule by @hoffa in #3003
  * chore(schema): update by @github-actions in #3002
  * fix: Fix add transform test by @GavinZZ in #3010
  * chore(schema): update by @github-actions in #3009
  * Merge main to develop by @aahung in #3012
  * chore: Add integration test service detector for
    SNS FilterPolicyScope by @aahung in #3015
  * chore: Add skip_using_service_detector to sns integ tests by @aahung in #3016
  * ci: Trigger gh actions on merge group by @aahung in #3017
  * fix: Defining CORS when ApiKeyRequired is true results in an
    OPTIONS method that requires an API key by @ConnorRobertson in #2981
  * chore: Upgrade ruff to 0.0.254 by @aahung in #3014
  * chore: Get rid of py2 import stuff by @aahung in #3018
  * chore: Enable pyupgrade check by @aahung in #3019
  * chore(schema): update by @github-actions in #3020
  * feat: Add EnableFunctionDefaultPermissions property to HTTP Api by @aaythapa in #3001
  * fix: integration test cors_with_apikey_and_cors by @ConnorRobertson in #3021
  * fix: Call correct exception when Connectors attribute is non-dict by @aaythapa in #3022
  * fix: Fix two places that could cause internal errors by @aahung in #3023
  * fix: cors integ test by @ConnorRobertson in #3024
  * Add Region & SetIdentifier properties to Route53 to enable
    latency based routing by @davidcolclazier in #2998
  * chore: Add type to metrics code and deprecate CWMetricsPublisher by @aahung in #3025
  * ci: Exclude samtranslator.internal from interface scan by @aahung in #3027
  * Merge main to develop by @hoffa in #3029
  * chore: update properties in schema with new docs by @aaythapa in #3026
  * chore(schema): update by @github-actions in #3030
  * fix: remove Region/SetIdentifier-related integration tests by @hoffa in #3033
- from version 1.62.0
  * chore: add stricter typing to construct assume role policy function by @pradhapanr in #2965
  * ci: Make transform test error json easier to diff/review by @aahung in #2968
  * feat: v2 of Start SFN execution policy by @ssenchenko in #2955
  * ci: Rename make black* to make format* by @aahung in #2970
  * fix: multiple mq source event policy name (add DynamicPolicyName) by @ssenchenko in #2953
  * fix: Truncate Event Bridge Rule if Id is over 64 characters by @GavinZZ in #2967
  * fix: Remove logical id change for Events Rule by @GavinZZ in #2972
  * fix: Useful error message when "Properties" key is
    missing in embedded connectors by @aaythapa in #2966
  * chore: Do not install “schema_source” to site-packages by @musicinmybrain in #2973
  * fix: Add MergeDefinitions property to Global Section by @GavinZZ in #2976
  * feat: add AlwaysDeploy to AWS::Serverless::Api by @hoffa in #2935
  * fix: Decouple samtranslator.models and *.intrinsics
    and add import tests by @aahung in #2977
  * chore: Merge main to develop by @aws-sam-cli-bot in #2979
  * ci: Upgrade ruff to 0.0.253 and enable more rules by @aahung in #2983
  * chore: Update Add Transform Tests Script by @GavinZZ in #2984
  * chore: Release 1.62.0 (to main) by @hoffa in #3028
- from version 1.61.0
  * chore(schema): add Connectors resource attribute to CFN resources by @hoffa in #2908
  * chore(schema): update by @github-actions in #2909
  * chore: add GeneratedProperty for CloudFormation Resource properties by @hoffa in #2907
  * refactor: preliminary changes for managed policy improvements by @hoffa in #2910
  * feat: New DisableFunctionDefaultPermissions property to block the
    creation of permissions resource from SAM API Auth by @aaythapa in #2885
  * feat: load managed policies locally by @hoffa in #2839
  * chore: Loose typing_extensions version requirement by @jakob-keller in #2916
  * feat: Appsync to DynamoDb connector by @ssenchenko in #2915
  * Move schema files by @GavinZZ in #2919
  * Add resource validator using schema models by @GavinZZ in #2917
  * fix: make MemorySize a pass-through by @hoffa in #2923
  * fix: Make pass-through properties pass-through in serverless::function by @aahung in #2924
  * docs: add link to GeneratedProperty by @hoffa in #2925
  * chore(schema): update by @github-actions in #2926
  * Remove property validations for lambda resources by @xazhao in #2928
  * Update doc path by @GavinZZ in #2931
  * chore: replace generated properties by GeneratedProperty() by @hoffa in #2934
  * fix: Fix two places that could cause uncatched errors by @aahung in #2930
  * Chore: another scan of replacing generated properties
    by GeneratedProperty() by @xazhao in #2937
  * chore: Batch update dev dependencies by @aahung in #2936
  * fix: appsync-ddb connector integ tests by @ssenchenko in #2938
  * chore(schema): update by @github-actions in #2946
  * chore: Remove "type: ignore" in samtranslator/translator by @aahung in #2947
  * Downgrade TriggerFunction node to v14 because 18 is not
    available in all regions by @ssenchenko in #2948
  * feat: Support SAM API MergeDefinitions property by @GavinZZ in #2943
  * chore: Replace py36 with py310 in black config by @aahung in #2949
  * One more fix for integ tests by @ssenchenko in #2951
  * chore: Update "Development Status" classifiers by @aahung in #2950
  * chore: remove soft template validation by @hoffa in #2961
  * chore: do not load managed policies if already ARN by @hoffa in #2964
- from version 1.60.1
  * fix: Decouple samtranslator.models and *.intrinsics and add import tests #2977
  * Release 1.60.1 (to main) by @aws-sam-cli-bot in #2978
- from version 1.60.0
  * chore: simpler way to update schema data by @hoffa in #2817
  * feat: CloudFormation docs in schema by @hoffa in #2816
  * feat: Allow resource attributes to be used on connectors by @aaythapa in #2822
  * feat: multiple destination connector by @xazhao in #2796
  * Sync Connectors from Profile Source of Truth by @awood45 in #2824
  * chore: Move schema source/generation out of samtranslator package by @aahung in #2825
  * fix(schema): more robust docs mapping by @hoffa in #2827
  * Add location tests by @GavinZZ in #2826
  * ci: mypy/pylint/format schema_source package by @aahung in #2828
  * Skip Location service integ tests if service is not supported by @GavinZZ in #2831
  * Revert last change and Re-add location exclusion in connector tests by @GavinZZ in #2832
  * ci: (experimental) Add ruff before pylint to lint the codebase by @aahung in #2833
  * ci: (experimental) Enable more ruff rules by @aahung in #2834
  * chore: update schema by @hoffa in #2836
  * ci: (experimental) Enable more ruff rules by @aahung in #2835
  * fix(schema): better docs parsing by @hoffa in #2837
  * ci: Remove pylint by @aahung in #2843
  * chore: use https to pull docs by @hoffa in #2846
  * ci: Upgrade ruff to 0.0.239 by @aahung in #2847
  * feat: New opt-in property to update Lambda version whenever
    a property changes by @aaythapa in #2838
  * ci(schema): scheduled updates by @hoffa in #2845
  * fix: workflow typo by @hoffa in #2848
  * chore(schema): update by @github-actions in #2849
  * fix(schema): improve docs parsing by @hoffa in #2850
  * docs: schema generation by @hoffa in #2851
  * docs: add workshop by @hoffa in #2852
  * chore: filter CFN docs by @hoffa in #2853
  * feat: Ssm paramater policy fix by @aaythapa in #2693
  * ci: add schema update PR body by @hoffa in #2855
  * chore(schema): update by @github-actions in #2858
  * fix(schema): support Alexa::* docs by @hoffa in #2859
  * chore(schema): update by @github-actions in #2860
  * ci(schema): add PR checks workaround to description by @hoffa in #2861
  * chore(schema): update by @github-actions in #2862
  * chore: remove tox and flake8 dependency by @hoffa in #2863
  * ci: Add public_interface command by @aahung in #2864
  * chore: remove docopt by @hoffa in #2865
  * Merge main to develop by @acristin in #2871
  * ci: Add public interface command check by @aahung in #2872
  * fix(sam-translate.py): add samtranslator to path by @hoffa in #2875
  * chore(schema): update by @github-actions in #2876
  * fix: recognize license by @hoffa in #2882
  * ci: Fix interface scan omits types (e.g., ConnectorResourceReference)
    by @aahung in #2880
  * ci: Add GH Action to detect compatibility breaking chages by @aahung in #2877
  * Adding metadata property for unsupported connector profile by @GavinZZ in #2879
  * chore: Remove outdated CompatibleRuntimes in basic_layer.yaml
    (from sam-cli#4672) by @aahung in #2881
  * ci: Use pull_request instead of pull_request_target in
    compatibility action by @aahung in #2883
  * chore: Upgrade ruff to 0.0.244 by @aahung in #2884
  * chore: Add decorator @deprecated and add it to is_str() by @aahung in #2889
  * chore: Upgrade mypy to 1.0.0 and type hint cw_timer by @aahung in #2890
  * chore: Upgrade black to 23.1.0 (depending on click 8)
    and format files by @aahung in #2892
  * chore: Use ParamSpec from PEP 612 by @aahung in #2891
  * chore: Remove click from dev.txt by @aahung in #2893
  * chore: Enable linting for tests and integration by @aahung in #2895
  * chore: Fix make integ-test as integration contains non-py files by @aahung in #2896
  * chore(schema): update by @github-actions in #2897
  * Use consistent method of determining AWS Partition from a region by @acristin in #2899
  * chore(schema): update by @github-actions in #2898
  * fix: Fix TestCustomDomains unit tests have side effect on others by @aahung in #2900
  * fix: Avoid hardcoded eventbus name in integ test by @aahung in #2901
  * fix: ChangeEmptyError constructor access self.stack_name
    before assigning by @aahung in #2902
  * fix: Add partition attribute to BaseTest by @acristin in #2903
  * Release 1.60.0 (to main) by @aws-sam-cli-bot in #2962
  * feat: Support DocumentDB event source by @msharris1
- from version 1.59.0
  * Allow Qualifier to be defined with Id in Serverless Connectors by @aaythapa in #2768
  * chore: Routinely add type hints by @aahung in #2771
  * chore: Cache get_partition_name to reduce transform latency by @aahung in #2774
  * chore: update schema docs by @hoffa in #2775
  * chore: use latest cfn-lint by @hoffa in #2777
  * Replace Fn::GetAtt Key.APIKeyId with Ref: Key by @acristin in #2779
  * Remove not implemented methods by @GavinZZ in #2780
  * chore: Remove all # type: ignore[attr-defined] by @aahung in #2783
  * refactor: Refactor ImplicitHttpApiPlugin and ImplicitRestApiPlugin by @aahung in #2784
  * chore: Enable some pylint rules and make our code comply by @aahung in #2788
  * Update sam_expect to be used for resource attributes by @aaythapa in #2789
  * chore: Loose pydantic version requirement by @aahung in #2790
  * chore: Loose pydantic version requirement ~1.10 -> ~1.8 by @aahung in #2791
  * chore: sort schema keys by @hoffa in #2792
  * chore: Adding more type hints by @GavinZZ in #2787
  * feat: unified SAM/CloudFormation schema by @hoffa in #2793
  * fix(schema): required pass-through fields by @hoffa in #2797
  * chore: more unified schema tests by @hoffa in #2798
  * chore: make unified schema the default by @hoffa in #2799
  * fix: better property title by @hoffa in #2800
  * feat: Attach connectors to source by @aaythapa in #2772
  * chore: Merge branch "main" into "develop" to apply the
    patch and version bump by @aahung in #2812
  * fix: Make StartingPosition not required in event source schemas by @aahung in #2813
  * chore: Add back argument "name" to BasePlugin for compatibility by @aahung in #2814
  * Release 1.59.0 (to main) by @aws-sam-cli-bot in #2870
- from version 1.58.1
  * chore: Add back samtranslator.model.types.is_str for compatibility by @aahung in #2810
- from version 1.58.0
  * chore: Update node.js version in test by @acristin in #2722
  * fix: Raise correct exception when "ResponseParameters"
    is not dict by @aahung in #2725
  * fix: Raise correct exception when DestinationConfig or
    DestinationConfig.x is not dict by @aahung in #2727
  * fix: Raise correct exception when S3 event referring to a
    bucket whose properties is not dict by @aahung in #2728
  * Add a cache on top of python27 hashing by @acristin in #2724
  * Fix warning when using default stage name and FailOnWarnings is on by @GavinZZ in #2726
  * fix: Handle when httpapi Auth could be null by @aahung in #2729
  * fix: Raise correct exception when Fn::If value is not a list by @aahung in #2731
  * Update caller credential partition by @GavinZZ in #2730
  * fix: Raise correct exception when rest api auth is not a dict by @aahung in #2732
  * Update DEVELOPMENT_GUIDE.md to use modern python by @acristin in #2733
  * docs: add clause to backward compatibility guidelines by @hoffa in #2723
  * Add typing and remove 'type: ignore' Part One by @GavinZZ in #2738
  * fix: Raise correct exception FindInMap used on parameters not a 2-level-map by @aahung in #2740
  * fix: Raise correct exception when bucket tags are not list by @aahung in #2742
  * fix: Raise correct exception when ApplicationId or Version of app is not valid by @aahung in #2741
  * chore: re-enable cfn-lint by @hoffa in #2745
  * Add typing and remove 'type: ignore' Part Two by @GavinZZ in #2744
  * chore: adding types part 1 by @aaythapa in #2746
  * Make jwtConfiguration fields lower case by @ssenchenko in #2737
  * fix: Deduplicate error message in InvalidResourceException by @aahung in #2748
  * fix: Prevent infinite recursion when resolving policy parameter when
    the parameter refs a CFN parameter with the same name by @aahung in #2751
  * fix: Extend validation of apiauth Identity sub values from Headers only by @aahung in #2747
  * chore: Make PropertyType.expected_type auto gen for dict and str by @aahung in #2752
  * Add typing and remove 'type: ignore' Part Three by @GavinZZ in #2750
  * fix: Raise correct exception when apigateway-endpoint-configuration
    is not a map by @aahung in #2753
  * chore: adding types part 2 by @aaythapa in #2749
  * refactor: Combine function/sfn Api event logics about adding Auth by @aahung in #2755
  * fix: Raise correct exception when Domain BasePath
    contains non-str items by @aahung in #2756
  * Type Ignore Fixes Part Four by @GavinZZ in #2757
  * Add support for AT_TIMESTAMP and StartingPositionTimestamp by @GavinZZ in #2758
  * Format policy_templates.json by @mustafa-sadiq in #2760
  * Added support for mTLS auth for MSK and Kafka by @mbfreder in #2690
  * chore: Add cw_timer to deepcopy in SwaggerEditor and OpenApiEditor by @aahung in #2764
  * chore: Optimize the use of deepcopy in Translator._get_function_names() by @aahung in #2765
  * chore: Format other files in samtranslator/policy_templates_data by @aahung in #2762
  * chore: Move some PullEventSource validations to subclasses by @aahung in #2767
  * feat: Support RuntimeManagementConfig by @valerena
- from version 1.57.0
  * feat: Support SQS Maximum Concurrency by @msharris1
- from version 1.56.0
  * ci: Allow build workflow to be triggered manually or by gh-cli by @aahung in #2593
  * feat: add UnescapeMappingTemplate to state machine Api event by @hoffa in #2591
  * chore: Type improvements in sam_resources.py by @aahung in #2594
  * fix: correct URL suffix by @hoffa in #2595
  * chore: Add CODEOWNERS file by @jfuss in #2592
  * docs: mention Property vs PropertyType by @hoffa in #2596
  * chore: Prevent bin/ from installed as a package by @aahung in #2597
  * chore: Add --add-test-metadata option to yaml formatter by @aahung in #2598
  * chore: Remove auto added yaml version in yaml formatter by @aahung in #2600
  * feat: Support "Name" for AWS::Serverless::HttpApi by @aahung in #2492
  * chore: Add PassThroughProperty and use it in :HttpApi Name by @aahung in #2601
  * docs: mention PassThroughProperty by @hoffa in #2602
  * fix: Raise correct exception when Api authorizer identity
    is not a dict by @aahung in #2603
  * chore: flexible jsonschema version by @jordanvance in #2511
  * fix: Raise correct exception when !Sub variable value
    (Parameter.Default) is not string by @aahung in #2607
  * fix: Raise correct exception when FunctionUrlConfig.Cors
    is not dict by @aahung in #2608
  * fix: Raise correct exception when swagger: securityDefinitions
    is not dict by @aahung in #2609
  * fix: Raise correct exception when swagger: responses.headers
    is not a dict by @aahung in #2610
  * fix: Raise correct exception when api authorizer
    is not a dict by @aahung in #2611
  * fix: KeyError: u'AWS_IAM' and add typing by @GavinZZ in #2604
  * adding support for all SSM Parameters types by @aaythapa in #2605
  * fix: Raise correct exception when restapi authorizer is not a dict by @aahung in #2613
  * fix: Raise correct exception when kafka SourceAccessConfigurations
    is not a list by @aahung in #2614
  * chore: Enforce formatting for yaml/json and add Test Metadata by @GavinZZ in #2617
  * feat: initial JSON schema by @hoffa in #2616
  * chore: add schema types for Connector and SimpleTable by @hoffa in #2618
  * chore: add schema types to Application by @hoffa in #2619
  * chore: add schema types to LayerVersion by @hoffa in #2620
  * fix: Handle when openapi/swagger security property is null by @aahung in #2615
  * chore: Experiment on unitify property value validation messages by @aahung in #2621
  * fix: Raise correct exception when Api.Domain is not a map by @aahung in #2622
  * feat: fast schema validation by @hoffa in #2624
  * chore: add state machine events schema skeleton by @hoffa in #2625
  * Maintainer list update: Add GavinZZ and Aayush and Connor by @GavinZZ in #2626
  * fix: Raise correct exception when Identity.Headers is not of valid type by @aahung in #2627
  * chore: add state machine schema types by @hoffa in #2628
  * Add Schema Type to AWS::Serverless::Lambda by @GavinZZ in #2623
  * Skeleton Lambda Events Schema by @GavinZZ in #2629
  * chore: ensure latest schema is always generated by @hoffa in #2632
  * fix: Raise correct exception when httpapi event
    RouteSettings is not dict by @aahung in #2630
  * fix: Raise correct exception when event OnFailure
    is not of valid type by @aahung in #2633
  * chore: add HttpApi schema by @hoffa in #2634
  * fix: Raise correct exception when DefaultAuthorizer
    is not of valid type by @aahung in #2636
  * Add detailed type to AWS::Serverless::Lambda Schema by @GavinZZ in #2635
  * fix: Raise correct exception when some properties are
    not dict when used with .get() by @aahung in #2637
  * Create SAM StateMachine without providing a role or policy by @ConnorRobertson in #2606
  * Add detailed type to AWS::Serverless::Api schema by @GavinZZ in #2638
  * chore: refactor schema by @hoffa in #2639
  * Add schema types to global section by @GavinZZ in #2641
  * chore: scaffolding for schema docs by @hoffa in #2644
  * Validate schema as unit test by @GavinZZ in #2643
  * fix: Raise correct exception when some properties are
    not dict when used dict methods by @aahung in #2646
  * chore: Add connect timeout to serverlessrepo clients by @aahung in #2650
  * Fix wrong types for schema by @GavinZZ in #2649
  * Use SamIntrinsicable to replace all Union[SamIntrinsics, T] by @GavinZZ in #2651
  * feat: more docs scaffolding + AWS::Serverless::Function by @hoffa in #2652
  * chore: docs to Connector/Application/LayerVersion/SimpleTable by @hoffa in #2654
  * chore: add schema docs to AWS::Serverless::Api by @hoffa in #2655
  * chore: add docs for Function event Type/Properties by @hoffa in #2656
  * add schema docs to AWS::Serverless::HttpApi by @GavinZZ in #2658
  * chore: add schema docs to AWS::Serverless::StateMachine by @aaythapa in #2657
  * Multi dest connector by @xazhao in #2647
  * feat: Role Path for AWS::Serverless::Function by @GavinZZ in #2659
  * chore: add JSON schema version by @hoffa in #2663
  * chore: remove feature request issue template by @hoffa in #2668
  * docs: update contribution guidelines for feature requests by @hoffa in #2669
  * chore: Refactor some chained dict.get() with dict_deep_get() by @aahung in #2648
  * feat: update transform test script to update ManagedPolicyArn
    with partion by @xazhao in #2660
  * Convert Relative Paths to Full Paths In Schema by @GavinZZ in #2671
  * fix: schema state machine Policies by @hoffa in #2672
  * chore: schema fix and polish by @hoffa in #2673
  * Release 1.55.0 (to develop) by @aws-sam-cli-bot in #2675
  * chore: more schema tests for invalid Type by @hoffa in #2677
  * chore: tighter schema type for RestApiId by @hoffa in #2679
  * chore: Add SnapStart into invalid Global error message by @aahung in #2678
  * Add a API test with BasePath containing hyphen by @GavinZZ in #2681
  * chore: Refactor OpenApiEditor and SwaggerEditor to
    reduce duplicate code by @aahung in #2682
  * fix: Raise corr...
- Update BuildRequires and Requires from setup.py
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 1.55.0:
  * RedrivePolicy added
  * chore: Type improvements in http api generator
  * feat: Add SnapStart support
* Mon Nov 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- Update to 1.54.0
  * chore: fix custom domain integration tests for feature toggle by @hnnasit
    in #2517
  * Revert "chore: fix custom domain integration tests for feature toggle" by
    @hnnasit in #2518
  * Release 1.52.0 (to develop) by @aws-sam-cli-bot in #2523
  * Release 1.53.0 (to develop) by @aws-sam-cli-bot in #2530
  * chore: rerun failing tests by @hoffa in #2527
  * docs: update PR template by @hoffa in #2531
  * chore: run tests with GitHub workflow by @hoffa in #2535
  * chore: pylint fix by @GavinZZ in #2538
  * chore: remove AppVeyor by @hoffa in #2539
  * Add Integration Test Deployer Logging Improvements by @awood45 in #2543
  * Upgrade Pylint Version and Fix Pylint Issues by @GavinZZ in #2540
  * Add ability to set State of EventBridge Rule by @sebastiankasprzak in #2524
  * Add Integ Test Skip Flag for EventBus by @awood45 in #2545
  * chore: Enable more pylint rules and fixes pylint issues by @GavinZZ in
    [#2544]
  * chore: add CodeQL by @hoffa in #2541
  * Enable more pylint rules and fixes pylint issues by @GavinZZ in #2547
  * fix: Correct kafka property names in generated event source mapping by
    @aahung in #2549
  * Enable more pylint rules and fixes pylint issues by @GavinZZ in #2548
  * chore: Add transform test creation script by @GavinZZ in #2551
  * chore: Add JSON formatter and format all JSON files in tests by @aahung in
    [#2553]
  * Do not change input file and exit if hardcoded partition used by @GavinZZ
    in #2554
  * feat: replace DependsOn to connector by its generated logical IDs by @hoffa
    in #2537
  * chore: use connector logical ID for DependsOn in integ test by @hoffa in
    [#2559]
  * Enable mypy --strict for future code by @xazhao in #2558
  * Bug fix: Fix DisableExecuteApiEndpoint bug fix by @aaythapa in #2560
  * Add ability to set Name of EventBridge Rule by @sebastiankasprzak in #2525
  * Remove unrecognized pylint options by @GavinZZ in #2555
  * chore: Make PropertyType and related validator typed by @aahung in #2562
  * chore: Make intrinsics helper functions typed by @aahung in #2563
  * chore: Type improvements initiated from adding all by @aahung in #2564
  * feat: Add support to Fn::GetAtt X.Y when looking up IAM role in serve… by
    @aahung in #2567
  * docs: new README by @hoffa in #2565
  * docs: use sam sync instead of sam deploy by @hoffa in #2569
  * docs: add SAM workshop, minor polish to README by @hoffa in #2571
  * chore: add Gitpod config, docs polish by @hoffa in #2573
  * Bug fix: Fix generated Lambda permission's SourceARN when $default path is
    used in HTTP API by @aaythapa in #2574
  * Better test for type of a variable by @kddejong in #2520
  * chore: Add yaml formatter and format yaml files in tests/ by @aahung in
    [#2577]
  * chore: Explicitly make our test yamls yaml 1.1 by @aahung in #2579
  * chore: clean up docs by @hoffa in #2580
  * docs: development guidelines by @hoffa in #2582
  * docs: add "add types" guideline by @hoffa in #2584
  * chore: add development guidelines to checklist by @hoffa in #2585
  * feat: Add ScheduleV2 for AWS::Scheduler::Schedule by @aahung
* Thu Oct 27 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.53.0
  * Verify profile variables have been replaced (#264)
  * Fix integ tests for feature toggle related to custom domain (#266)
  * feat: Event filtering for MQ, MSK, SMK (#134) (#265)
  * Fixed indentation in custom_domains_edge yaml file (#273)
  * Always copy profile (#274)
  * Increase api_with_authorizer retry delay (#275)
  * Add retry-once to connector tests (#276)
  * Use node14 runtime in connector integ tests (#278)
  * add a step to clean up unused network interfaces in the precreated subnets
  * Do not retry on SkipTest (#280)
- Update to 1.52.0
  * fix: Update Slack Invite link by @jfuss in #2490
  * feat: adding support for SSM Parameters (string) as Type by @LautaroJayat
    in #2469
  * chore: Updated maintainers by @lucashuy in #2494
  * Release 1.51.0 (to develop) by @aws-sam-cli-bot in #2500
  * docs: update README by @hoffa in #2501
  * feat: Add State Property to EventBridgeRule EventSource in Function by
    @nallenscott in #2497
  * feat: Added UserAttributeUpdateSettings to Cognito by @lucashuy in #2503
  * chore: Use pre-created SAR app during integration tests by @mndeveci in
    [#2507]
  * chore: Add test name to request logging and remove default region from
    pytest.ini by @qingchm in #2513
  * chore: Only do request logging when internal flag is provided by @qingchm
    in #2514
* Tue Sep 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.51.0
  * chore: Add missing import and add partition into base test
    for integration test by @qingchm in #2463
  * Release 1.49.0 (to develop) by @aws-sam-cli-bot in #2465
  * Revert "chore: Add missing import and add partition into
    base test for integration test" by @qingchm in #2466
  * Update methods in Metrics class to accept timestamp by @hawflau in #2470
  * Release 1.50.0 (to develop) by @aws-sam-cli-bot in #2471
  * feat: Add State Property to Schedule EventSource in
    StateMachine by @konoui in #2468
  * Test: Upgrade integration test cases lambda resources
    runtimes to nodejs14.x by @moelasmar in #2474
  * Add validation for S3 NotificationConfiguration in
    Serverless Functin… by @hawflau in #2473
  * chore: Change FeatureToggleAppConfigConfigProvider to accept AppConfig
    client, so SAM-T can send a monitored client. by @moelasmar in #2480
  * chore: Add basic mypy check (no behavior change) by @aahung in #2488
  * chore: Integration test improvements with ApiKey skips and
    retry time by @qingchm in #2487
- from version 1.50.0
  * chore: Skip self managed kafka tests by @qingchm in #2461
  * chore: Add required skipifs for integration tests by @qingchm in #2462
  * feat: Support ConsumerGroupId for Kafka events
- from version 1.49.0
  * Fix EventSource Schedule passes Enabled to State by @lightpriest in #1666
  * chore: Add capability to disable S3 Events integration
    test cases. by @moelasmar in #2454
  * chore: Add region skip condition and retry for http
    test by @qingchm in #2455
  * Add validation for swagger security when ApiKeyRequired
    is true by @hawflau in #2456
  * Release 1.48.0 (to develop) by @aws-sam-cli-bot in #2457
- from version 1.48.0
  * chore: [Foss] Sync public: Update region service exclusion
    list by @mingkun2020 in #2427
  * chore: [Foss] Sync public: Add skip condition for http
    by @mingkun2020 in #2429
  * chore: [Foss] Sync public: Add skip condition for rest
    api tests by @mingkun2020 in #2432
  * chore: [Foss] Sync public: Add back hash verification
    by @mingkun2020 in #2434
  * feat: [Foss] Sync public: remove region service exclusion
    and inclusion list by @mingkun2020 in #2437
  * chore: [Foss] Sync public: Add skip condition for EFS
    tests by @mingkun2020 in #2436
  * fix: [Foss] Sync public: Update custom domain tests
    resource by @mingkun2020 in #2435
  * feat: Add support for the `FailOnWarnings` property on
    `AWS::Serverless::Api` by @nialdaly in #2417
  * chore: [Foss] Sync public: Add retry and logging for dlq/http/cors
    flaky requests by @mingkun2020 in #2428
  * Fix route53 record set groups by @hawflau in #2408
  * Release 1.47.0 (to develop) by @hawflau in #2444
  * chore: sync foss changes by @mndeveci in #2445
- from version 1.47.0
  * test: Add logging for relevant Amazon headers useful
    for debugging by @mildaniel in #2390
  * Update python3.6 runtime in integration test templates
    by @hawflau in #2395
  * test: Add tests for intrinsics support for DefinitionBody
    by @torresxb1 in #2407
  * fix: check null method for open api by @mndeveci in #2409
  * Release 1.46.0 (to develop) by @hawflau in #2411
  * validate Http Api Authorizers identity Header by @jonife in #2339
  * fix: update error message to contain the normalized method rather
    than the method dict by @mndeveci in #2414
  * fix: use array of exceptions instead of str for
    InvalidDocumentException by @mndeveci in #2416
  * fix: Allow Implicit HTTP APIs to write when value of
    method is None by @jfuss in #2413
  * blogs, video and workshop update in readme by @praneetap in #2422
  * fix: Fail gracefully when AutoPublishAlias is an empty string by @jfuss in #2425
- from version 1.46.0
  * Validation for API property Model by @jonife in #2340
  * refactor: Make _get_function_names less verbose by @aahung in #2223
  * Release/v1.44.0 (to develop) by @hawflau in #2363
  * Add validation for SecretsManagerKmsKeyId by @jonife in #2323
  * Bump minimal boto3 version to 1.19.5 by @hawflau in #2365
  * fix: Add retries to SAR service calls on throttle by @mildaniel in #2352
  * fix: use formatting instead of concatenating when preparing
    the exception messages by @mndeveci in #2369
  * Release/v1.45.0 by @hawflau in #2371
  * sync foss changes by @mingkun2020 in #2359
  * feat: Add a built-in AWS_IAM authorizer for HTTP APIs by @harrisonhjones in #1924
  * reduce CloudFormation template size by @PatMyron in #2368
  * chore: Add checkbox for intrinsic validation changes by @mildaniel in #2379
  * Adding ApiKeySourceType. by @lee-11 in #2298
  * chore: Update PR template wording by @mildaniel in #2383
  * chore(test): Move assert_ to assertTrue by @jfuss in #2382
  * fix: use InvalidDocumentException instead of ValueError by @mndeveci in #2376
  * chore: remove sys.path override by @jfuss in #2380
  * fix: wrap InvalidTemplateException's with InvalidDocumentException
    by @torresxb1 in #2391
  * fix: pass the condition attribute to the generated function url
    resources for the conditional functions by @moelasmar in #2388
  * fix: raise InvalidEventException for incorrect Properties field
    usage for Api event type by @mndeveci in #2393
  * fix: apply resource conditions to DeploymentPreference
    resources by @keetonian in #1578
  * feat: improve new PR and issue labeling for triaging by @torresxb1 in #2400
  * Furl AutopublishAlias bug fix by @jonife in #2378
  * Update FURL integ test to test invoke by @hawflau in #2401
  * Update policy_templates.rst by @danxgh10 in #2403
  * Release 1.46.0 (to main) by @hawflau in #2412
- Add patch to skip tests that require a network connection
  * skip-tests-require-network.patch
* Thu May  5 2022 pgajdos@suse.com
- version update to 1.45.0
  * Feat FURL by @jonife @valerena in #2370
  * Feat /tmp config by @slowpokesnail in #2362
  * Fix no allowed origin by @c2tarun in #2180
  * Raise InvalidEventException when RestApiId/ApiId is not resolved to a string by @aahung in #2213
  * Raise a validation exception if the responses section in an openApi definition path is not a dictionary object by @moelasmar in #2214
  * chore: Add auto PR labeler by @jfuss in #2219
  * Fix DestinationConfig in streaming event sources by @hawflau in #2215
  * fix: handle non-dict DefinitionBody path item in _openapi_postprocess by @torresxb1 in #2216
  * Run unit tests in parallel by @aahung in #2222
  * Handle when HttpApi resource doesn't have properties by @aahung in #2221
  * Chore: Only add labels on open of PRs by @jfuss in #2225
  * feat: Lambda URLs by @mndeveci in #2231
  * Revert "feat: Lambda URLs (#2229)" by @mndeveci in #2233
  * Handle when function http event auth is not a string by @aahung in #2234
  * chore: bump version to 1.42.0 by @mndeveci in #2235
  * Revert "chore: bump version to 1.42.0" by @CoshUS in #2237
  * release: 1.42.0 by @mndeveci in #2243
  * fix: open api set_path_default_authorizer by @mndeveci in #2248
  * Validate swagger path item objects by @aahung in #2251
  * Validate swagger method value is a valid dict before processing by @aahung in #2250
  * fix: fix validation errors log message that calls join on a string by @torresxb1 in #2245
  * [FOSS] hot fix and improvement by @mingkun2020 in #2207
  * fix: Check type of resource type is a string by @mildaniel in #2252
  * fix: open api set_path_default_authorizer (#2248) by @mndeveci in #2262
  * fix: open api set_path_default_authorizer (#2248) by @mndeveci in #2261
  * Do not abort SAR loop on throttling by @marekaiv in #2240
  * Improve error message for an invalid ResourcePolicy element by @marekaiv in #2271
  * Fixing DisableExecuteApiEndpoint property for REST and adding integ t… by @sattigar in #2272
  * fix: Py27hash fix by @torresxb1 in #2182
  * chore: bump version to 1.43.0 by @hawflau in #2276
  * Update integ test expected result to incorporate py27hashfix changes by @hawflau in #2286
  * [minor docs] Updates examples link to current non-archived repo by @Phuurl in #2277
  * fix: Raise exception if provided Auth.Authorizers.Identity isn't a dict by @mildaniel in #2273
  * fix: Correct CognitoUserPool SmsConfiguration validation type by @lafiosca in #1582
  * fix: accept empty components property in Open Api Definition by @moelasmar in #2296
  * Corrected gitpod link to open this repo instead of aws-sam-cli by @JiteshKanojia in #2170
  * docs: updating EventBridgeRule documentation by @TheWesDias in #2236
  * Update INTEGRATION_TESTS.md by @hawflau in #2300
  * Clean up Py2 dependencies and update to use native unittest.mock by @hawflau in #2299
  * Add security policy by @tylersouthwick in #1937
  * fix: Add handling for OpenApi definition that has tags with invalid format by @qingchm in #2295
  * Remove six as dependency by @hawflau in #2302
  * Fix all warnings in tests by @hawflau in #2303
  * fix: Raise Invalid Resource When DisableExecuteApiEndpoint: False And Has No DefinitionBody by @CoshUS in #2285
  * handle 'Invalid Swagger Document' and refactor some validation into Swagger Editor constructor by @torresxb1 in #2263
  * Update PR template to add integration tests in checklist by @hawflau in #2306
  * Conditionally adding metadata to translated resources by @andrew-glenn in #2224
  * Improve exception processing for Route53 with invalid type by @wchengru in #2284
  * fix: Check S3 Lambda Configuration Type is a List by @mildaniel in #2310
  * tests: add test for DefaultAuthorizers not a string in API by @jfuss in #2313
  * fix: ValueError is not caught by int() by @wchengru in #2305
  * fix: Add Checks for Authorizer Types in API Event Sources by @mildaniel in #2307
  * Add method for determining service availability in a region by @marekaiv in #2321
  * chore: Enable pylint on project by @jfuss in #2326
  * update validation for dead letter queue by @jonife in #2324
  * fix: fix paths IF intrinsic bug by @torresxb1 in #2330
  * Py27dict deepcopy performance by @marekaiv in #2331
  * Update function_with_custom_code_deploy integration test case by @hawflau in #2320
  * fix: Update tag count check for apigw v2 resources by @mildaniel in #2333
  * chore: Remove duplicated Docs by @jfuss in #2334
  * validate Lambda Authorizer property identity by @jonife in #2322
  * chore: update setup.cfg key to use underscore by @mgorny in #2051
  * test: Add retries on flaky integration test by @mildaniel in #2343
  * fix: remove py3.6 support and add py3.9 and py3.10 by @mndeveci in #2311
  * Revert "chore: bump version to 1.43.0" by @hawflau in #2345
  * Revert "handle 'Invalid Swagger Document' and refactor some validatio… by @torresxb1 in #2346
  * chore: Version bump to 1.43.0 by @hawflau in #2347
  * Release/v1.43.0 by @mildaniel in #2358
- fix build
- python-mock is not required for build
* Tue Mar 15 2022 Dirk Müller <dmueller@suse.com>
- use python_expand for fdupes
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.42.0:
  * Increase PageSize of ListPolicies Paginator
  * Support VIRTUAL_HOST as Type for SourceAccessConfiguration for MQ events
  * Add modes support for RestApi
  * ARM support
  * Add ValidateBody/ValidateParameters attribute to API models
  * Adding support for metric publishing
  * Self Managed Kafka as event source support
  * adding OwnershipVerificationCertificateArn and DisableExecuteApiEndpoint to APIs
  * event source filtering
* Thu Jun 10 2021 Dirk Müller <dmueller@suse.com>
- update to 1.36.0:
  * Optimize shared API usage plan handling
  * Resource level attributes support
* Mon Mar 29 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v1.35.0
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Thu Oct  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.27.0
  + docs: fix link to all_policy_templates example file
  + fix: Allow Ref in CompatibleRuntimes property of AWS::Serverless::LayerVersion
  + Adding Tracing property to State Machine resource
  + Add new arguments to allow vpc/vpce endpoints as intrinsics
- from 1.26.0
  + feat: Add support for VPCEndpointIds in EndpointConfiguration
  + fix: Adding authorization scopes as list validation in ApiGatewayAuthorizer (v1 and v2)
  + MSK event type support for AWS::Serverless::Function
* Wed Jul  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.25.0
  * chore: Exclude test modules in whl
  * feat: Add Step Function Resource
  * fix : missing UserPool properties
  * fix: resource policy generation for {path+}
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon May  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.22.0:
  * Many parsing changes to enumerate, fixes for new syntax
- Fix the saml-translate binary to be executable
* Mon May  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
- Do not ship generic folder with tests in sitelib
* Fri Nov 22 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Disable tests on SLE-12 as the testsuite is
  incompatible with Python 3.4
- Drop patch to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + ast_drop-compatible-releases-operator.patch
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update the patch ast_drop-compatible-releases-operator.patch to
  not pull enum34 on python3
* Thu Jul 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix build on SLE-12
  + Add python to BuildRequires for suse_version < 1500
  + Set LANG to en_US.UTF8 before running testsuite
  + Refresh ast_drop-compatible-releases-operator.patch to
    strip "python_version<"3.4"" from install_requires
* Wed Jun  5 2019 Todd R <toddrme2178@gmail.com>
- Switch to github sources which include tests
- Enable tests
- Fix dependencies
- Add commandline tool
* Fri May 17 2019 Scott Wulf <swulf@suse.com>
- Upgrade to 1.11.0
  * Add ReservedConcurrentExecutions to globals
  * Fix ElasticsearchHttpPostPolicy resource reference
  * Support using AWS::Region in Ref and Sub
  * Documentation and examples updates
  * Add VersionDescription property to Serverless::Function
  * Update ServerlessRepoReadWriteAccessPolicy
  * Add additional template validation
- Upgrade to 1.10.0
  * Add GSIs to DynamoDBReadPolicy and DynamoDBCrudPolicy
  * Add DynamoDBReconfigurePolicy
  * Add CostExplorerReadOnlyPolicy and OrganizationsListAccountsPolicy
  * Add EKSDescribePolicy
  * Add SESBulkTemplatedCrudPolicy
  * Add FilterLogEventsPolicy
  * Add SSMParameterReadPolicy
  * Add SESEmailTemplateCrudPolicy
  * Add s3:PutObjectAcl to S3CrudPolicy
  * Add allow_credentials CORS option
  * Add support for AccessLogSetting and CanarySetting Serverless::Api properties
  * Add support for X-Ray in Serverless::Api
  * Add support for MinimumCompressionSize in Serverless::Api
  * Add Auth to Serverless::Api globals
  * Remove trailing slashes from APIGW permissions
  * Add SNS FilterPolicy and an example application
  * Add Enabled property to Serverless::Function event sources
  * Add support for PermissionsBoundary in Serverless::Function
  * Fix boto3 client initialization
  * Add PublicAccessBlockConfiguration property to S3 bucket resource
  * Make PAY_PER_REQUEST default mode for Serverless::SimpleTable
  * Add limited support for resolving intrinsics in Serverless::LayerVersion
  * SAM now uses Flake8
  * Add example application for S3 Events written in Go
  * Updated several example applications
* Mon Jan 21 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.9.0
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + ast_drop-compatible-releases-operator.patch
